﻿namespace TWA.MaskedTextBoxRadClientDataSource.Controllers
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Net;
    using System.Net.Http;
    using System.Web.Http;
    using System.Web.Routing;

    [RoutePrefix("api/pricing")]
    public class PricingController : ApiController
    {
        readonly ValuesRepository repository = new ValuesRepository();

        [Route("")]
        public IEnumerable<Pricing> GetAllPricing()
        {
            return repository.GetAll();
        }
        
        [Route("{id}")]
        public IHttpActionResult GetPricing(int id)
        {
            var item = repository.Get(id);

            if(item == null)
            {
                throw new HttpResponseException(HttpStatusCode.NotFound);
            }
            return Ok(item);
        }

        public void PutPricing(int id, Pricing value)
        {
            value.ID = id;
            if (!repository.Update(value))
            {
                throw new HttpResponseException(HttpStatusCode.NotFound);
            }
        }

        public void DeletePricing(int id)
        {
            Pricing item = repository.Get(id);

            if(item == null)
            {
                throw new HttpResponseException(HttpStatusCode.NotFound);
            }

            repository.Remove(id);
        }
    }

    public class ValuesRepository
    {
        private readonly List<Pricing> values;
        private int currentID = 11;

        public ValuesRepository()
        {
            values = new List<Pricing>(new Pricing[]
            {
                new Pricing { ID= 1, Price = 13.45m },
                new Pricing { ID= 2, Price = 1343.54m },
                new Pricing { ID= 3, Price = 134.12m },
                new Pricing { ID= 4, Price = 17865.21m },
                new Pricing { ID= 5, Price = 132.23m },
                new Pricing { ID= 6, Price = 189.32m },
                new Pricing { ID= 7, Price = 134.56m },
                new Pricing { ID= 8, Price = 15.65m },
                new Pricing { ID= 9, Price = 100.78m },
                new Pricing { ID= 10, Price = 10.87m },
                new Pricing { ID= 11, Price = 12.89m },
            });
        }

        public IEnumerable<Pricing> GetAll()
        {
            return values;
        }

        public Pricing Get(int id)
        {
            return values.FirstOrDefault(v => v.ID == id);
        }

        public Pricing Add(Pricing item)
        {
            if(item == null)
            {
                throw new ArgumentNullException("item");
            }

            item.ID = ++currentID;
            values.Add(item);
            return item;
        }

        public void Remove(int id)
        {
            values.RemoveAll(v => v.ID == id);
        }

        public bool Update(Pricing item)
        {
            if(item == null)
            {
                throw new ArgumentNullException("item");
            }

            int index = values.FindIndex(v => v.ID == item.ID);

            if(index == -1)
            {
                return false;
            }

            values.RemoveAt(index);
            values.Add(item);
            return true;
        }
    }

    public class Pricing
    {
        public int ID { get; set; }
        public decimal Price { get; set; }
    }
}
